@@ -5,7 +5,10 @@ def get_definition(jump_frames,*args,**kwargs):
     """Returns the definition of a function or a class from inside"""
     frame = inspect.currentframe()
     frame = inspect.getouterframes(frame)[jump_frames]
-    string = inspect.getframeinfo(frame[0]).code_context[0].strip()
+    if frame is not None:
+        string = inspect.getframeinfo(frame[0]).code_context[0].strip()
+    else:
+        string=""
     return(string)
     
 def analyze_definition(string):    
